from __future__ import absolute_import, division, print_function

__all__ = [
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__", '__maintainer__',
    '__maintainer_email__',
]

__title__ = "flake8-import-order"
__summary__ = (
    "Flake8 and pylama plugin that checks the ordering of import statements."
)
__uri__ = "https://github.com/PyCQA/flake8-import-order"

__version__ = "0.18.2"

__author__ = "Alex Stapleton"
__email__ = "alexs@prol.etari.at"

__maintainer__ = 'Phil Jones'
__maintainer_email__ = 'philip.graham.jones+flake8-import@gmail.com'

__license__ = "LGPLv3"
__copyright__ = "Copyright 2013-2016 %s" % __author__
